@@ -2,12 +2,15 @@ import click
 import pdb
 import requests
 import sys
+from stoobly_agent.app.cli.helpers.test_facade import TestFacade
 
 from stoobly_agent.app.settings import Settings
-from stoobly_agent.config.constants import test_origin, test_strategy
+from stoobly_agent.config.constants import custom_headers, test_strategy
 from stoobly_agent.lib.api.keys.request_key import InvalidRequestKey
+from stoobly_agent.lib.api.keys.test_key import TestKey
 from stoobly_agent.lib.utils.conditional_decorator import ConditionalDecorator
 
+from .helpers.print_service import handle_on_request_response, handle_on_test_response
 from .helpers.request_facade import RequestFacade
 from .helpers.tabulate_print_service import tabulate_print
 from .helpers.validations import *
@@ -35,8 +38,7 @@ def request(ctx):
 @click.option('--size', default=10)
 @click.option('--without-headers', is_flag=True, default=False, help='Disable printing column headers.')
 def list(**kwargs):
-  without_headers = kwargs['without_headers']
-  del kwargs['without_headers']
+  print_options = __select_print_options(kwargs)
 
   settings = Settings.instance()
   project_key = None
@@ -54,12 +56,7 @@ def list(**kwargs):
   if len(requests_response['list']) == 0:
     print('No requests found.')
   else:
-    tabulate_print(
-      requests_response['list'], 
-      filter=['components' , 'created_at', 'endpoint_id', 'id', 'position', 'project_id', 'scenario_id', 'scheme', 'starred', 'updated_at', 'url'],
-      headers=not without_headers,
-      select=kwargs.get('select'),
-    )
+    __print(requests_response['list'], **print_options)
 
 @request.command(
   help="Replay a request"
@@ -77,10 +74,10 @@ def replay(**kwargs):
 
     validate_scenario_key(kwargs['scenario_key'])
 
-  request = RequestFacade(Settings.instance())
-  res = __replay(request.replay, kwargs)
+  kwargs['on_response'] = handle_on_request_response
 
-  print(res.content)
+  request = RequestFacade(Settings.instance())
+  __replay(request.replay, kwargs)
 
 @request.command(
   help="Test a request"
@@ -89,15 +86,18 @@ def replay(**kwargs):
 @click.option('--strategy', default=test_strategy.DIFF, help=f"{test_strategy.CUSTOM} | {test_strategy.DIFF} | {test_strategy.FUZZY}")
 @click.argument('request_key')
 def test(**kwargs):
-  validate_request_key(kwargs['request_key'])
+  request_key = validate_request_key(kwargs['request_key'])
 
   if kwargs.get('report_key'):
     validate_report_key(kwargs['report_key'])
 
-  request = RequestFacade(Settings.instance())
-  res = __replay(request.test, kwargs)
+  settings = Settings.instance()
+  kwargs['on_response'] = lambda context: handle_on_test_response(
+    context, request_key.project_id, settings
+  )
 
-  print(res.json())
+  request = RequestFacade(settings)
+  __replay(request.test, kwargs)
 
 @click.group(
   epilog="Run 'stoobly-agent request response COMMAND --help' for more information on a command.",
@@ -135,4 +135,23 @@ def __replay(handler, kwargs) -> requests.Response:
     return handler(request_key, kwargs) 
   except InvalidRequestKey:
     print('Error: Invalid request key.', file=sys.stderr)
-    sys.exit(1)
\ No newline at end of file
+    sys.exit(1)
+
+def __print(requests, **kwargs):
+    tabulate_print(
+      requests, 
+      filter=['components' , 'created_at', 'endpoint', 'endpoint_id', 'id', 'position', 'project_id', 'scenario_id', 'scheme', 'starred', 'updated_at', 'url'],
+      headers=not kwargs.get('without_headers'),
+      select=kwargs.get('select') or []
+    )
+
+def __select_print_options(kwargs):
+    print_options = {
+        'select': kwargs['select'],
+        'without_headers': kwargs['without_headers']
+    }
+
+    del kwargs['without_headers']
+    del kwargs['select']
+
+    return print_options
\ No newline at end of file
