@@ -1,9 +1,14 @@
 import click
 import pdb
+import requests
 import sys
+from stoobly_agent.app.cli.helpers.print_service import handle_on_request_response, handle_on_test_response
+from stoobly_agent.app.cli.helpers.test_facade import TestFacade
+from stoobly_agent.app.proxy.replay.context import ReplayContext
 
 from stoobly_agent.app.settings import Settings
-from stoobly_agent.config.constants import test_strategy
+from stoobly_agent.config.constants import custom_headers, test_strategy
+from stoobly_agent.lib.api.keys.test_key import TestKey
 
 from .helpers.scenario_facade import ScenarioFacade
 from .helpers.tabulate_print_service import tabulate_print
@@ -26,18 +31,19 @@ def scenario(ctx):
 @click.option('--without-headers', is_flag=True, default=False, help='Disable printing column headers.')
 @click.argument('name')
 def create(**kwargs):
+    print_options = __select_print_options(kwargs)
+
     settings = Settings.instance()
     project_key = resolve_project_key_and_validate(kwargs, settings) 
 
     scenario = ScenarioFacade(settings)
-    res = scenario.create(project_key, kwargs['name'], kwargs['description'])
 
-    tabulate_print(
-        [res],
-        filter=['created_at', 'project_id', 'starred', 'updated_at'],
-        headers=not kwargs.get('without_headers'),
-        select=kwargs.get('select')
-    )
+    try:
+        res = scenario.create(project_key, kwargs['name'], kwargs['description'])
+    except AssertionError as e:
+        return print(e, file=sys.stderr)
+
+    __print([res], **print_options)
 
 @scenario.command(
     help="Replay a scenario"
@@ -55,8 +61,9 @@ def replay(**kwargs):
 
         validate_scenario_key(kwargs['scenario_key'])
 
-    scenario = ScenarioFacade(Settings.instance())
+    kwargs['on_response'] = handle_on_request_response
 
+    scenario = ScenarioFacade(Settings.instance())
     scenario.replay(kwargs.get('key'), kwargs)
 
 @scenario.command(
@@ -66,13 +73,17 @@ def replay(**kwargs):
 @click.option('--strategy', help=f"{test_strategy.CUSTOM} | {test_strategy.DIFF} | {test_strategy.FUZZY}")
 @click.argument('key')
 def test(**kwargs):
-    validate_scenario_key(kwargs['key'])
+    scenario_key = validate_scenario_key(kwargs['key'])
 
     if kwargs.get('report_key'):
         validate_report_key(kwargs['report_key'])
 
-    scenario = ScenarioFacade(Settings.instance())
+    settings = Settings.instance()
+    kwargs['on_response'] = lambda context: handle_on_test_response(
+        context, scenario_key.project_id, settings
+    )
 
+    scenario = ScenarioFacade(settings)
     scenario.test(kwargs['key'], kwargs)
 
 @scenario.command(
@@ -80,41 +91,65 @@ def test(**kwargs):
 )
 @click.option('--page', default=0)
 @click.option('--project-key', help='Project to list scenarios from.')
+@click.option('--select', multiple=True, help='Select column(s) to display.')
+@click.option('--size', default=10)
 @click.option('--sort-by', default='created_at', help='created_at|name')
 @click.option('--sort-order', default='desc', help='asc | desc')
-@click.option('--size', default=10)
-@click.option('--select', multiple=True, help='Select column(s) to display.')
 @click.option('--without-headers', is_flag=True, default=False, help='Disable printing column headers.')
 def list(**kwargs):
-    without_headers = kwargs['without_headers']
-    del kwargs['without_headers']
+    print_options = __select_print_options(kwargs)
 
     settings = Settings.instance()
     project_key = resolve_project_key_and_validate(kwargs, settings)
     del kwargs['project_key']
 
     scenario = ScenarioFacade(settings)
-    scenarios_response = scenario.index(project_key, kwargs)
+
+    try:
+        scenarios_response = scenario.index(project_key, kwargs)
+    except AssertionError as e:
+        return print(e, file=sys.stderr)
 
     if len(scenarios_response['list']) == 0:
         print('No scenarios found.')
     else:
-        tabulate_print(
-            scenarios_response['list'], 
-            filter=['created_at', 'project_id', 'starred', 'updated_at'],
-            headers=not without_headers,
-            select=kwargs.get('select')
-        )
+        __print(scenarios_response['list'], **print_options) 
 
 @scenario.command(
     help="Describe scenario"
 )
+@click.option('--select', multiple=True, help='Select column(s) to display.')
+@click.option('--without-headers', is_flag=True, default=False, help='Disable printing column headers.')
 @click.argument('key', required=False)
 def show(**kwargs):
+    print_options = __select_print_options(kwargs)
+
     settings = Settings.instance()
     scenario_key = resolve_scenario_key_and_validate(kwargs, settings)
     scenario = ScenarioFacade(settings)
 
-    scenario_response = scenario.show(scenario_key)
+    try:
+        scenario_response = scenario.show(scenario_key)
+    except AssertionError as e:
+        return print(e, file=sys.stderr)
 
-    tabulate_print([scenario_response], filter=['created_at', 'project_id', 'starred', 'updated_at'])
\ No newline at end of file
+    __print([scenario_response], **print_options)
+
+def __print(scenarios, **kwargs):
+    tabulate_print(
+        scenarios, 
+        filter=['created_at', 'priority', 'project_id', 'starred', 'updated_at'],
+        headers=not kwargs.get('without_headers'),
+        select=kwargs.get('select') or []
+    )
+
+def __select_print_options(kwargs):
+    print_options = {
+        'select': kwargs['select'],
+        'without_headers': kwargs['without_headers']
+    }
+
+    del kwargs['without_headers']
+    del kwargs['select']
+
+    return print_options
\ No newline at end of file
