@@ -7,9 +7,9 @@ from mitmproxy.net.http.request import Request as MitmproxyRequest
 from stoobly_agent.app.settings.constants import firewall_action, intercept_mode
 from stoobly_agent.app.settings.filter_rule import FilterRule
 from stoobly_agent.app.settings.firewall_rule import FirewallRule
-from stoobly_agent.app.settings import Settings, parameter_rule
-from stoobly_agent.config.constants import custom_headers, mode
-from stoobly_agent.lib.api.keys.project_key import ProjectKey
+from stoobly_agent.app.settings import Settings
+from stoobly_agent.config.constants import custom_headers, mode, request_origin
+from stoobly_agent.lib.api.keys.project_key import InvalidProjectKey, ProjectKey
 
 class InterceptSettings:
 
@@ -20,10 +20,17 @@ class InterceptSettings:
 
     if request:
       self.__headers = request.headers
-    
-    project_key = ProjectKey(self.project_key)
-    project_id = project_key.id
 
+    project_id = None
+
+    try: 
+      project_key = ProjectKey(self.project_key)
+      project_id = project_key.id
+    except InvalidProjectKey:
+      pass
+
+    # If no valid project key is provided, use default settings,
+    # Otherwise, set settings for the project
     self.__data_rules = self.__settings.proxy.data.data_rules(project_id)
     self.__filter_rules = self.__settings.proxy.filter.filter_rules(project_id)
     self.__firewall_rules = self.__settings.proxy.firewall.firewall_rules(project_id)
@@ -71,9 +78,14 @@ class InterceptSettings:
 
     return self.__data_rules.scenario_key
 
+  @scenario_key.setter
+  def scenario_key(self, v):
+    self.__data_rules.scenario_key = v
+
   @property
-  def report_key(headers: MitmproxyRequest.headers) -> Union[str, None]:
-    return headers.get(custom_headers.REPORT_KEY)
+  def report_key(self) -> Union[str, None]:
+    if self.__headers and custom_headers.REPORT_KEY in self.__headers:
+      return self.__headers[custom_headers.REPORT_KEY]
 
   @property
   def policy(self):
@@ -127,8 +139,18 @@ class InterceptSettings:
   
   @property
   def test_strategy(self):
+    if self.__headers and custom_headers.TEST_STRATEGY in self.__headers:
+      return self.__headers[custom_headers.TEST_STRATEGY]
+
     return self.__data_rules.test_strategy
 
+  @property
+  def request_origin(self):
+    if self.__headers and custom_headers.REQUEST_ORIGIN in self.__headers:
+      return self.__headers[custom_headers.REQUEST_ORIGIN]
+
+    return request_origin.WEB
+
   def __select_filter_rules(self):
     rules = []
 
