@@ -1,42 +1,50 @@
 import pdb
 
-from stoobly_agent.lib.api.interfaces import RequestShowResponse, RequestsIndexQueryParams
-from stoobly_agent.lib.api.keys.scenario_key import InvalidScenarioKey, ScenarioKey
 from stoobly_agent.app.models.request_model import RequestModel
 from stoobly_agent.app.models.schemas.request import Request
+from stoobly_agent.lib.api.endpoints_resource import EndpointsResource
+from stoobly_agent.lib.api.interfaces import RequestShowResponse, RequestsIndexQueryParams
+from stoobly_agent.lib.api.keys.scenario_key import ScenarioKey
 
+from .context import ReplayContext
 from .replay_request_service import replay as replay_request, ReplayRequestOptions
+from .trace_context import TraceContext
+
+PAGE_SIZE = '25'
 
 def replay(scenario_key: str, request_model: RequestModel, options: ReplayRequestOptions):
   scenario_key = ScenarioKey(scenario_key)
+  settings = request_model.settings
+  endpoints_resource = EndpointsResource(settings.remote.api_url, settings.remote.api_key)
+  trace_context = TraceContext(endpoints_resource)
 
   page = 0
   count = 0
-  l = []
 
   while True:
     requests_index = __get_requests(
-      request_model, scenario_key, { 'page': page, 'size': '25' }
+      request_model, scenario_key, { 'page': page, 'size': PAGE_SIZE }
     )
 
     requests = list(map(lambda request: Request(request), requests_index['list']))
     total = requests_index['total']
   
     if not requests or len(requests) == 0:
-      return l
+      return
 
     for request_partial in requests:
+      count += 1
+
       request_id = request_partial.id
-      request = Request(__get_request(request_model, scenario_key, request_id))
-
-      response = replay_request(request, **options) 
-
-      l.append(response)
-
-    count += len(requests)
+      request_response = __get_request(request_model, scenario_key, request_id)
+      if not request_response:
+        continue
+      
+      context = ReplayContext(Request(request_response)).with_sequence(count)
+      trace_context.with_replay_context(context, lambda: replay_request(context, **options))
 
     if count >= total:
-      return l
+      return
 
     page += 1
 
@@ -53,7 +61,9 @@ def __get_requests(
     'size': query_params.get('size'),
   })
 
-def __get_request(request_model: RequestModel, scenario_key: ScenarioKey, request_id: int) -> RequestShowResponse:
+def __get_request(
+  request_model: RequestModel, scenario_key: ScenarioKey, request_id: int
+) -> RequestShowResponse:
   project_id = scenario_key.project_id
 
   return request_model.show(
