@@ -1,12 +1,14 @@
 MOCK_POLICY = 'X-Mock-Policy'
-MOCK_REQUEST_ID = 'X-Mock-Request-Id'
+MOCK_REQUEST_ID = 'X-Stoobly-Request-Id'
+MOCK_REQUEST_ENDPOINT_ID = 'X-Stoobly-Request-Endpoint-Id'
 DO_PROXY = 'X-Do-Proxy'
 PROJECT_KEY = 'X-Project-Key'
 PROXY_MODE = 'X-Proxy-Mode'
 RECORD_POLICY = 'X-Record-Policy'
 REPORT_KEY = 'X-Report-Key'
-RESPONSE_LATENCY = 'X-Response-Latency'
+REQUEST_ORIGIN = 'X-Proxy-Request-Origin'
+RESPONSE_LATENCY = 'X-Stoobly-Request-Response-Latency'
 SCENARIO_KEY = 'X-Scenario-Key'
 SERVICE_URL = 'X-Service-Url'
-TEST_ORIGIN = 'X-Test-Origin'
+TEST_ID = 'X-Stoobly-Test-Id'
 TEST_STRATEGY = 'X-Test-Strategy'
\ No newline at end of file
