@@ -1,7 +1,9 @@
+import requests
 import urllib
+import pdb
 
 from ..logger import Logger
-from .interfaces import ProjectCreateParams, ProjectsIndexQueryParams, ProjectsIndexResponse
+from .interfaces import ProjectCreateParams, ProjectsIndexQueryParams
 from .stoobly_api import StooblyApi
 
 class ProjectsResource(StooblyApi):
@@ -12,10 +14,16 @@ class ProjectsResource(StooblyApi):
 
     return self.post(url, headers=self.default_headers, data=params)
 
-  def index(self, **query_params: ProjectsIndexQueryParams) -> ProjectsIndexResponse:
+  def index(self, **query_params: ProjectsIndexQueryParams) -> requests.Response:
     url = f"{self.service_url}/{self.PROJECTS_ENDPOINT}"
 
     Logger.instance().debug(f"{self.LOG_ID}.request_response:{url}?{urllib.parse.urlencode(query_params)}")
 
     return self.get(url, headers=self.default_headers, params=query_params)
 
+  def show(self, project_id: int, **query_params) -> requests.Response:
+    url = f"{self.service_url}/{self.PROJECTS_ENDPOINT}/{project_id}"
+
+    Logger.instance().debug(f"{self.LOG_ID}.request_response:{url}?{urllib.parse.urlencode(query_params)}")
+
+    return self.get(url, headers=self.default_headers, params=query_params)
\ No newline at end of file
