@@ -1,7 +1,7 @@
 import logging
 import os
 
-from .env_vars import LOG_LEVEL
+from stoobly_agent.config.constants.env_vars import LOG_LEVEL
 
 class Logger:
     _instance = None
@@ -27,3 +27,13 @@ class Logger:
 
         return logging
 
+class bcolors:
+    HEADER = '\033[95m'
+    OKBLUE = '\033[94m'
+    OKCYAN = '\033[96m'
+    OKGREEN = '\033[92m'
+    WARNING = '\033[93m'
+    FAIL = '\033[91m'
+    ENDC = '\033[0m'
+    BOLD = '\033[1m'
+    UNDERLINE = '\033[4m'
\ No newline at end of file
